@@ -10,7 +10,7 @@ use strict;
 use vars qw($VERSION);
 use IO::File;
 
-$VERSION = "0.12"; # $Id: //depot/tftp/TFTP.pm#1 $
+$VERSION = "0.15"; # $Id: //depot/tftp/TFTP.pm#5 $
 
 sub RRQ	  () { 01 } # read request
 sub WRQ	  () { 02 } # write request
@@ -122,9 +122,11 @@ sub get {
     my $file = $local;
     unless(ref($local)) {
 	unlink($file);
-	$local = IO::File->new($file,O_WRONLY|O_CREAT);
+	$local = IO::File->new($file,O_WRONLY|O_TRUNC|O_CREAT);
     }
 
+    binmode $local if $self->{'Mode'} eq 'octet';
+
     my($len,$pkt);
     while($len = sysread($io,$pkt,10240)) {
 	if($len < 0) {
@@ -170,6 +172,8 @@ sub put {
     return $io
 	unless defined($local) && defined($io);
 
+    binmode $local if $self->{'Mode'} eq 'octet';
+
     my($len,$pkt);
     while($len = sysread($local,$pkt,10240)) {
 	if($len < 0) {
@@ -552,7 +556,8 @@ sub _read {
 	    return _abort($self);
 	}
 
-	send($sock,$self->{'pkt'},0,$self->{'peer'});
+	send($sock,$self->{'pkt'},0,$self->{'peer'})
+	  if $self->{'peer'};
 
 	if ($self->{'Debug'}) {
 	    print STDERR "${sock} << ---- retry=${retry}\n";
@@ -618,6 +623,9 @@ sub _send_data {
 	_dumppkt($sock,1,$opkt)
 	    if $self->{'Debug'};
     }
+    elsif (length($self->{'obuf'}) == 0 and $self->{'blksize'} == 1) {
+	# ignore
+    }
     elsif($^W) {
 	require Carp;
 	Carp::carp("Net::TFTP: Buffer underflow");
@@ -870,6 +878,6 @@ it under the same terms as Perl itself.
 
 =for html <hr>
 
-I<$Id: //depot/tftp/TFTP.pm#1 $>
+I<$Id: //depot/tftp/TFTP.pm#5 $>
 
 =cut
